searchData={"items":[{"type":"module","title":"Ecto.DevLogger","doc":"An alternative logger for Ecto queries.\n\nIt inlines bindings into the query, so it is easy to copy-paste logged SQL and run it in any IDE for debugging without\nmanual transformation of common elixir terms to string representation (binary UUID, DateTime, Decimal, json, etc).\nAlso, it highlights db time to make slow queries noticeable. Source table and inlined bindings are highlighted as well.","ref":"Ecto.DevLogger.html"},{"type":"function","title":"Ecto.DevLogger.handler_id/1","doc":"Gets the handler_id for a given Repo.","ref":"Ecto.DevLogger.html#handler_id/1"},{"type":"function","title":"Ecto.DevLogger.install/2","doc":"Attaches `telemetry_handler/4` to application.\n\nReturns the result from the call to `:telemetry.attach/4` or `:ok` if the repo has default logging enabled.","ref":"Ecto.DevLogger.html#install/2"},{"type":"function","title":"Options - Ecto.DevLogger.install/2","doc":"* `:log_repo_name` - when truthy will add the repo name into the log.\n* `:ignore_event` - a callback which allows to skip some telemetry events thus skip printing logs.\nBy default, the library ignores events from `Oban` and events related to migration queries.\nThese checks are not overridable by `:ignore_event` callback and have priority over it.\n* `:before_inline_callback` - a callback which allows to modify the query before inlining of bindings.\nYou can use this option to format the query using external utility, like `pgformatter`, etc.","ref":"Ecto.DevLogger.html#install/2-options"},{"type":"function","title":"Ecto.DevLogger.telemetry_handler/4","doc":"Telemetry handler which logs queries.","ref":"Ecto.DevLogger.html#telemetry_handler/4"},{"type":"function","title":"Ecto.DevLogger.uninstall/1","doc":"Detaches a previously attached handler for a given Repo.\n\nReturns the result from the call to `:telemetry.detach/1`","ref":"Ecto.DevLogger.html#uninstall/1"},{"type":"type","title":"Ecto.DevLogger.option/0","doc":"","ref":"Ecto.DevLogger.html#t:option/0"},{"type":"protocol","title":"Ecto.DevLogger.PrintableParameter","doc":"A protocol to print various data structures as valid SQL expressions.\n\n`to_expression/1` is the main function and `to_string_literal/1` is an optional helper for it.\n\n`Ecto.DevLogger` tries to represent complex terms, like arrays (lists) and composite types (tuples)\nas string literal first. Not all terms are easy/efficient/whatever to represent as strings, so if\n`to_string_literal/1` returns a string for all elements inside the array,\nthen array will be represented as string as well. Otherwise, array will be represented using `ARRAY` constructor:\n\n    iex> Ecto.DevLogger.PrintableParameter.to_expression([\"Elixir\", \"Ecto\"])\n    \"'{Elixir,Ecto}'\"\n\n    iex> Ecto.DevLogger.PrintableParameter.to_expression([\"Elixir\", \"Ecto\", <<153>>])\n    \"ARRAY['Elixir','Ecto',DECODE('mQ==','BASE64')]\"\n\nThe same is true for composite types (tuples):\n\n    iex> Ecto.DevLogger.PrintableParameter.to_expression({\"Elixir\", \"Ecto\"})\n    \"'(Elixir,Ecto)'\"\n\n    iex> Ecto.DevLogger.PrintableParameter.to_expression({\"Elixir\", \"Ecto\", <<153>>})\n    \"ROW('Elixir','Ecto',DECODE('mQ==','BASE64'))\"","ref":"Ecto.DevLogger.PrintableParameter.html"},{"type":"function","title":"Ecto.DevLogger.PrintableParameter.to_expression/1","doc":"Converts term to a valid SQL expression.","ref":"Ecto.DevLogger.PrintableParameter.html#to_expression/1"},{"type":"function","title":"Ecto.DevLogger.PrintableParameter.to_string_literal/1","doc":"Converts term to a string literal.","ref":"Ecto.DevLogger.PrintableParameter.html#to_string_literal/1"},{"type":"type","title":"Ecto.DevLogger.PrintableParameter.t/0","doc":"All the types that implement this protocol.","ref":"Ecto.DevLogger.PrintableParameter.html#t:t/0"},{"type":"extras","title":"README","doc":"# Ecto.DevLogger\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ecto_dev_logger.svg)](https://hex.pm/packages/ecto_dev_logger)\n\nAn alternative logger for Ecto queries.\n\nIt inlines bindings into the query, so it is easy to copy-paste logged SQL and run it in any IDE for debugging without\nmanual transformation of common elixir terms to string representation (binary UUID, DateTime, Decimal, json, etc).\nAlso, it highlights db time to make slow queries noticeable. Source table and inlined bindings are highlighted as well.\n\n![before and after](./assets/screenshot.png)","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"The package can be installed by adding `ecto_dev_logger` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ecto_dev_logger, \"~> 0.11\"}\n  ]\nend\n```\n\nThen disable default logger for your repo in config file for dev mode:\n```elixir\nif config_env() == :dev do\n  config :my_app, MyApp.Repo, log: false\nend\n```\nAnd install telemetry handler in `MyApp.Application`:\n```elixir\nEcto.DevLogger.install(MyApp.Repo)\n```\nTelemetry handler will be installed *only* if `log` configuration value is set to `false`.\n\nThat's it.\n\nThe docs can be found at [https://hexdocs.pm/ecto_dev_logger](https://hexdocs.pm/ecto_dev_logger).","ref":"readme.html#installation"},{"type":"extras","title":"Development Only Installation - README","doc":"If you turn off repo logging for any reason in production, you can configure `ecto_dev_logger` to *only* be available\nin development. In your `mix.exs`, restrict the installation to `:dev`:\n\n```elixir\ndef deps do\n  [\n    {:ecto_dev_logger, \"~> 0.10\", only: :dev}\n  ]\nend\n```\n\nIn `MyApp.Application`, an additional function is required:\n\n```elixir\ndefmodule MyApp.Application do\n  @moduledoc \"...\"\n\n  def start(_type, _args) do\n    maybe_install_ecto_dev_logger()\n\n    # ...\n  end\n\n  if Code.ensure_loaded?(Ecto.DevLogger) do\n    defp maybe_install_ecto_dev_logger, do: Ecto.DevLogger.install(MyApp.Repo)\n  else\n    defp maybe_install_ecto_dev_logger, do: :ok\n  end\n\n  # ...\nend\n```","ref":"readme.html#development-only-installation"},{"type":"extras","title":"Format queries - README","doc":"It is possible to format queries using a `:before_inline_callback` option.\nHere is an example of setup using [pgFormatter](https://github.com/darold/pgFormatter) as an external utility:\n```elixir\ndefmodule MyApp.Application do\n  def start(_type, _args) do\n    Ecto.DevLogger.install(MyApp.Repo, before_inline_callback: &__MODULE__.format_sql_query/1)\n  end\n\n  def format_sql_query(query) do\n    case System.shell(\"echo $SQL_QUERY | pg_format -\", env: [{\"SQL_QUERY\", query}], stderr_to_stdout: true) do\n      {formatted_query, 0} -> String.trim_trailing(formatted_query)\n      _ -> query\n    end\n  end\nend\n```","ref":"readme.html#format-queries"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}